@@ -141,7 +141,8 @@ Make sure you have the correct URI that is the main web2py directory.
 This should include your `applications` and `gluon` directories.""")
 
     app = TestApp(wsgibase, extra_environ=dict(
-                TEST_APP=_TEST_APP_KEY
+                TEST_APP=_TEST_APP_KEY,
+                TEST_METHOD="WebTest",
     ))
 
     return app
@@ -164,12 +165,13 @@ This should include your `applications` and `gluon` directories.""")
                     import_models=True,
                     dir=dir,
                     extra_request = {
-                            'wsgi': {'environ': {'TEST_APP': _TEST_APP_KEY}}
+                            'wsgi': {'environ': {
+                                'TEST_APP': _TEST_APP_KEY,
+                                'TEST_METHOD': 'FakeEnv'
+                            }}
                         }
                     )
 
-   # _env['wsgi'] = {'environ': {'TEST_APP': _TEST_APP_KEY}}
-
     if controller:
        execfile(os.path.join(dir, 'controllers', controller + '.py'), _env)
 
